@@ -8,7 +8,7 @@ use Icinga\Module\Kubernetes\Common\Auth;
 use Icinga\Module\Kubernetes\Common\Database;
 use Icinga\Module\Kubernetes\Common\ViewMode;
 use Icinga\Module\Kubernetes\Model\PersistentVolume;
-use Icinga\Module\Kubernetes\Web\ListController;
+use Icinga\Module\Kubernetes\Web\Controller\ListController;
 use ipl\Orm\Query;
 
 class PersistentvolumesController extends ListController
